# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicPropertyAssociationFilterBranchFiltersInner(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "_property": "str",
        "filter_type": "str",
        "operation": "PublicSurveyMonkeyValueFilterValueComparison",
        "list_id": "str",
        "coalescing_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "to_object_type": "str",
        "association_type_id": "int",
        "association_category": "str",
        "to_object_type_id": "str",
        "operator": "str",
        "enable_tracking": "bool",
        "pruning_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "page_url": "str",
        "cta_name": "str",
        "event_id": "str",
        "form_id": "str",
        "page_id": "str",
        "event_type_id": "str",
        "filter_lines": "list[PublicEventFilterMetadata]",
        "subscription_type": "str",
        "subscription_ids": "list[str]",
        "accepted_statuses": "list[str]",
        "channel": "str",
        "accepted_opt_states": "list[str]",
        "business_unit_id": "str",
        "campaign_id": "str",
        "survey_id": "str",
        "value_comparison": "PublicSurveyMonkeyValueFilterValueComparison",
        "survey_question": "str",
        "survey_answer_row_id": "str",
        "survey_answer_col_id": "str",
        "webinar_id": "str",
        "click_url": "str",
        "level": "str",
        "app_id": "str",
        "email_id": "str",
        "privacy_name": "str",
        "search_terms": "list[str]",
        "entity_type": "str",
        "ad_network": "str",
        "search_term_type": "str",
        "metadata": "PublicInListFilterMetadata",
        "property_with_object_id": "str",
        "should_accept": "bool",
        "source": "str",
    }

    attribute_map = {
        "_property": "property",
        "filter_type": "filterType",
        "operation": "operation",
        "list_id": "listId",
        "coalescing_refine_by": "coalescingRefineBy",
        "to_object_type": "toObjectType",
        "association_type_id": "associationTypeId",
        "association_category": "associationCategory",
        "to_object_type_id": "toObjectTypeId",
        "operator": "operator",
        "enable_tracking": "enableTracking",
        "pruning_refine_by": "pruningRefineBy",
        "page_url": "pageUrl",
        "cta_name": "ctaName",
        "event_id": "eventId",
        "form_id": "formId",
        "page_id": "pageId",
        "event_type_id": "eventTypeId",
        "filter_lines": "filterLines",
        "subscription_type": "subscriptionType",
        "subscription_ids": "subscriptionIds",
        "accepted_statuses": "acceptedStatuses",
        "channel": "channel",
        "accepted_opt_states": "acceptedOptStates",
        "business_unit_id": "businessUnitId",
        "campaign_id": "campaignId",
        "survey_id": "surveyId",
        "value_comparison": "valueComparison",
        "survey_question": "surveyQuestion",
        "survey_answer_row_id": "surveyAnswerRowId",
        "survey_answer_col_id": "surveyAnswerColId",
        "webinar_id": "webinarId",
        "click_url": "clickUrl",
        "level": "level",
        "app_id": "appId",
        "email_id": "emailId",
        "privacy_name": "privacyName",
        "search_terms": "searchTerms",
        "entity_type": "entityType",
        "ad_network": "adNetwork",
        "search_term_type": "searchTermType",
        "metadata": "metadata",
        "property_with_object_id": "propertyWithObjectId",
        "should_accept": "shouldAccept",
        "source": "source",
    }

    def __init__(
        self,
        _property=None,
        filter_type="CONSTANT",
        operation=None,
        list_id=None,
        coalescing_refine_by=None,
        to_object_type=None,
        association_type_id=None,
        association_category=None,
        to_object_type_id=None,
        operator=None,
        enable_tracking=None,
        pruning_refine_by=None,
        page_url=None,
        cta_name=None,
        event_id=None,
        form_id=None,
        page_id=None,
        event_type_id=None,
        filter_lines=None,
        subscription_type=None,
        subscription_ids=None,
        accepted_statuses=None,
        channel=None,
        accepted_opt_states=None,
        business_unit_id=None,
        campaign_id=None,
        survey_id=None,
        value_comparison=None,
        survey_question=None,
        survey_answer_row_id=None,
        survey_answer_col_id=None,
        webinar_id=None,
        click_url=None,
        level=None,
        app_id=None,
        email_id=None,
        privacy_name=None,
        search_terms=None,
        entity_type=None,
        ad_network=None,
        search_term_type=None,
        metadata=None,
        property_with_object_id=None,
        should_accept=None,
        source=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicPropertyAssociationFilterBranchFiltersInner - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self.__property = None
        self._filter_type = None
        self._operation = None
        self._list_id = None
        self._coalescing_refine_by = None
        self._to_object_type = None
        self._association_type_id = None
        self._association_category = None
        self._to_object_type_id = None
        self._operator = None
        self._enable_tracking = None
        self._pruning_refine_by = None
        self._page_url = None
        self._cta_name = None
        self._event_id = None
        self._form_id = None
        self._page_id = None
        self._event_type_id = None
        self._filter_lines = None
        self._subscription_type = None
        self._subscription_ids = None
        self._accepted_statuses = None
        self._channel = None
        self._accepted_opt_states = None
        self._business_unit_id = None
        self._campaign_id = None
        self._survey_id = None
        self._value_comparison = None
        self._survey_question = None
        self._survey_answer_row_id = None
        self._survey_answer_col_id = None
        self._webinar_id = None
        self._click_url = None
        self._level = None
        self._app_id = None
        self._email_id = None
        self._privacy_name = None
        self._search_terms = None
        self._entity_type = None
        self._ad_network = None
        self._search_term_type = None
        self._metadata = None
        self._property_with_object_id = None
        self._should_accept = None
        self._source = None
        self.discriminator = None

        self._property = _property
        self.filter_type = filter_type
        self.operation = operation
        self.list_id = list_id
        self.coalescing_refine_by = coalescing_refine_by
        if to_object_type is not None:
            self.to_object_type = to_object_type
        self.association_type_id = association_type_id
        self.association_category = association_category
        if to_object_type_id is not None:
            self.to_object_type_id = to_object_type_id
        self.operator = operator
        if enable_tracking is not None:
            self.enable_tracking = enable_tracking
        self.pruning_refine_by = pruning_refine_by
        self.page_url = page_url
        self.cta_name = cta_name
        self.event_id = event_id
        if form_id is not None:
            self.form_id = form_id
        self.page_id = page_id
        self.event_type_id = event_type_id
        self.filter_lines = filter_lines
        self.subscription_type = subscription_type
        self.subscription_ids = subscription_ids
        self.accepted_statuses = accepted_statuses
        self.channel = channel
        self.accepted_opt_states = accepted_opt_states
        if business_unit_id is not None:
            self.business_unit_id = business_unit_id
        self.campaign_id = campaign_id
        self.survey_id = survey_id
        self.value_comparison = value_comparison
        self.survey_question = survey_question
        if survey_answer_row_id is not None:
            self.survey_answer_row_id = survey_answer_row_id
        if survey_answer_col_id is not None:
            self.survey_answer_col_id = survey_answer_col_id
        if webinar_id is not None:
            self.webinar_id = webinar_id
        if click_url is not None:
            self.click_url = click_url
        self.level = level
        self.app_id = app_id
        self.email_id = email_id
        self.privacy_name = privacy_name
        self.search_terms = search_terms
        self.entity_type = entity_type
        self.ad_network = ad_network
        self.search_term_type = search_term_type
        if metadata is not None:
            self.metadata = metadata
        self.property_with_object_id = property_with_object_id
        self.should_accept = should_accept
        if source is not None:
            self.source = source

    @property
    def _property(self):
        """Gets the _property of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The _property of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self.__property

    @_property.setter
    def _property(self, _property):
        """Sets the _property of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param _property: The _property of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type _property: str
        """
        if self.local_vars_configuration.client_side_validation and _property is None:  # noqa: E501
            raise ValueError("Invalid value for `_property`, must not be `None`")  # noqa: E501

        self.__property = _property

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The filter_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param filter_type: The filter_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["CONSTANT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def operation(self):
        """Gets the operation of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The operation of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: PublicSurveyMonkeyValueFilterValueComparison
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param operation: The operation of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type operation: PublicSurveyMonkeyValueFilterValueComparison
        """
        if self.local_vars_configuration.client_side_validation and operation is None:  # noqa: E501
            raise ValueError("Invalid value for `operation`, must not be `None`")  # noqa: E501

        self._operation = operation

    @property
    def list_id(self):
        """Gets the list_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The list_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param list_id: The list_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type list_id: str
        """
        if self.local_vars_configuration.client_side_validation and list_id is None:  # noqa: E501
            raise ValueError("Invalid value for `list_id`, must not be `None`")  # noqa: E501

        self._list_id = list_id

    @property
    def coalescing_refine_by(self):
        """Gets the coalescing_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The coalescing_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._coalescing_refine_by

    @coalescing_refine_by.setter
    def coalescing_refine_by(self, coalescing_refine_by):
        """Sets the coalescing_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param coalescing_refine_by: The coalescing_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type coalescing_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """
        if self.local_vars_configuration.client_side_validation and coalescing_refine_by is None:  # noqa: E501
            raise ValueError("Invalid value for `coalescing_refine_by`, must not be `None`")  # noqa: E501

        self._coalescing_refine_by = coalescing_refine_by

    @property
    def to_object_type(self):
        """Gets the to_object_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The to_object_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._to_object_type

    @to_object_type.setter
    def to_object_type(self, to_object_type):
        """Sets the to_object_type of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param to_object_type: The to_object_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type to_object_type: str
        """

        self._to_object_type = to_object_type

    @property
    def association_type_id(self):
        """Gets the association_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The association_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: int
        """
        return self._association_type_id

    @association_type_id.setter
    def association_type_id(self, association_type_id):
        """Sets the association_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param association_type_id: The association_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type association_type_id: int
        """
        if self.local_vars_configuration.client_side_validation and association_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `association_type_id`, must not be `None`")  # noqa: E501

        self._association_type_id = association_type_id

    @property
    def association_category(self):
        """Gets the association_category of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The association_category of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._association_category

    @association_category.setter
    def association_category(self, association_category):
        """Sets the association_category of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param association_category: The association_category of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type association_category: str
        """
        if self.local_vars_configuration.client_side_validation and association_category is None:  # noqa: E501
            raise ValueError("Invalid value for `association_category`, must not be `None`")  # noqa: E501

        self._association_category = association_category

    @property
    def to_object_type_id(self):
        """Gets the to_object_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The to_object_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._to_object_type_id

    @to_object_type_id.setter
    def to_object_type_id(self, to_object_type_id):
        """Sets the to_object_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param to_object_type_id: The to_object_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type to_object_type_id: str
        """

        self._to_object_type_id = to_object_type_id

    @property
    def operator(self):
        """Gets the operator of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The operator of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param operator: The operator of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def enable_tracking(self):
        """Gets the enable_tracking of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The enable_tracking of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tracking

    @enable_tracking.setter
    def enable_tracking(self, enable_tracking):
        """Sets the enable_tracking of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param enable_tracking: The enable_tracking of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type enable_tracking: bool
        """

        self._enable_tracking = enable_tracking

    @property
    def pruning_refine_by(self):
        """Gets the pruning_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The pruning_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._pruning_refine_by

    @pruning_refine_by.setter
    def pruning_refine_by(self, pruning_refine_by):
        """Sets the pruning_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param pruning_refine_by: The pruning_refine_by of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type pruning_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """
        if self.local_vars_configuration.client_side_validation and pruning_refine_by is None:  # noqa: E501
            raise ValueError("Invalid value for `pruning_refine_by`, must not be `None`")  # noqa: E501

        self._pruning_refine_by = pruning_refine_by

    @property
    def page_url(self):
        """Gets the page_url of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The page_url of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._page_url

    @page_url.setter
    def page_url(self, page_url):
        """Sets the page_url of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param page_url: The page_url of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type page_url: str
        """
        if self.local_vars_configuration.client_side_validation and page_url is None:  # noqa: E501
            raise ValueError("Invalid value for `page_url`, must not be `None`")  # noqa: E501

        self._page_url = page_url

    @property
    def cta_name(self):
        """Gets the cta_name of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The cta_name of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._cta_name

    @cta_name.setter
    def cta_name(self, cta_name):
        """Sets the cta_name of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param cta_name: The cta_name of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type cta_name: str
        """
        if self.local_vars_configuration.client_side_validation and cta_name is None:  # noqa: E501
            raise ValueError("Invalid value for `cta_name`, must not be `None`")  # noqa: E501

        self._cta_name = cta_name

    @property
    def event_id(self):
        """Gets the event_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The event_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param event_id: The event_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type event_id: str
        """
        if self.local_vars_configuration.client_side_validation and event_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def form_id(self):
        """Gets the form_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The form_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param form_id: The form_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type form_id: str
        """

        self._form_id = form_id

    @property
    def page_id(self):
        """Gets the page_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The page_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._page_id

    @page_id.setter
    def page_id(self, page_id):
        """Sets the page_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param page_id: The page_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type page_id: str
        """
        if self.local_vars_configuration.client_side_validation and page_id is None:  # noqa: E501
            raise ValueError("Invalid value for `page_id`, must not be `None`")  # noqa: E501

        self._page_id = page_id

    @property
    def event_type_id(self):
        """Gets the event_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The event_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._event_type_id

    @event_type_id.setter
    def event_type_id(self, event_type_id):
        """Sets the event_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param event_type_id: The event_type_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type event_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and event_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_type_id`, must not be `None`")  # noqa: E501

        self._event_type_id = event_type_id

    @property
    def filter_lines(self):
        """Gets the filter_lines of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The filter_lines of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: list[PublicEventFilterMetadata]
        """
        return self._filter_lines

    @filter_lines.setter
    def filter_lines(self, filter_lines):
        """Sets the filter_lines of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param filter_lines: The filter_lines of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type filter_lines: list[PublicEventFilterMetadata]
        """
        if self.local_vars_configuration.client_side_validation and filter_lines is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_lines`, must not be `None`")  # noqa: E501

        self._filter_lines = filter_lines

    @property
    def subscription_type(self):
        """Gets the subscription_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The subscription_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._subscription_type

    @subscription_type.setter
    def subscription_type(self, subscription_type):
        """Sets the subscription_type of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param subscription_type: The subscription_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type subscription_type: str
        """
        if self.local_vars_configuration.client_side_validation and subscription_type is None:  # noqa: E501
            raise ValueError("Invalid value for `subscription_type`, must not be `None`")  # noqa: E501

        self._subscription_type = subscription_type

    @property
    def subscription_ids(self):
        """Gets the subscription_ids of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The subscription_ids of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: list[str]
        """
        return self._subscription_ids

    @subscription_ids.setter
    def subscription_ids(self, subscription_ids):
        """Sets the subscription_ids of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param subscription_ids: The subscription_ids of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type subscription_ids: list[str]
        """
        if self.local_vars_configuration.client_side_validation and subscription_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `subscription_ids`, must not be `None`")  # noqa: E501

        self._subscription_ids = subscription_ids

    @property
    def accepted_statuses(self):
        """Gets the accepted_statuses of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The accepted_statuses of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: list[str]
        """
        return self._accepted_statuses

    @accepted_statuses.setter
    def accepted_statuses(self, accepted_statuses):
        """Sets the accepted_statuses of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param accepted_statuses: The accepted_statuses of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type accepted_statuses: list[str]
        """
        if self.local_vars_configuration.client_side_validation and accepted_statuses is None:  # noqa: E501
            raise ValueError("Invalid value for `accepted_statuses`, must not be `None`")  # noqa: E501

        self._accepted_statuses = accepted_statuses

    @property
    def channel(self):
        """Gets the channel of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The channel of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._channel

    @channel.setter
    def channel(self, channel):
        """Sets the channel of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param channel: The channel of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type channel: str
        """
        if self.local_vars_configuration.client_side_validation and channel is None:  # noqa: E501
            raise ValueError("Invalid value for `channel`, must not be `None`")  # noqa: E501

        self._channel = channel

    @property
    def accepted_opt_states(self):
        """Gets the accepted_opt_states of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The accepted_opt_states of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: list[str]
        """
        return self._accepted_opt_states

    @accepted_opt_states.setter
    def accepted_opt_states(self, accepted_opt_states):
        """Sets the accepted_opt_states of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param accepted_opt_states: The accepted_opt_states of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type accepted_opt_states: list[str]
        """
        if self.local_vars_configuration.client_side_validation and accepted_opt_states is None:  # noqa: E501
            raise ValueError("Invalid value for `accepted_opt_states`, must not be `None`")  # noqa: E501

        self._accepted_opt_states = accepted_opt_states

    @property
    def business_unit_id(self):
        """Gets the business_unit_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The business_unit_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._business_unit_id

    @business_unit_id.setter
    def business_unit_id(self, business_unit_id):
        """Sets the business_unit_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param business_unit_id: The business_unit_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type business_unit_id: str
        """

        self._business_unit_id = business_unit_id

    @property
    def campaign_id(self):
        """Gets the campaign_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The campaign_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param campaign_id: The campaign_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type campaign_id: str
        """
        if self.local_vars_configuration.client_side_validation and campaign_id is None:  # noqa: E501
            raise ValueError("Invalid value for `campaign_id`, must not be `None`")  # noqa: E501

        self._campaign_id = campaign_id

    @property
    def survey_id(self):
        """Gets the survey_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The survey_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._survey_id

    @survey_id.setter
    def survey_id(self, survey_id):
        """Sets the survey_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param survey_id: The survey_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type survey_id: str
        """
        if self.local_vars_configuration.client_side_validation and survey_id is None:  # noqa: E501
            raise ValueError("Invalid value for `survey_id`, must not be `None`")  # noqa: E501

        self._survey_id = survey_id

    @property
    def value_comparison(self):
        """Gets the value_comparison of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The value_comparison of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: PublicSurveyMonkeyValueFilterValueComparison
        """
        return self._value_comparison

    @value_comparison.setter
    def value_comparison(self, value_comparison):
        """Sets the value_comparison of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param value_comparison: The value_comparison of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type value_comparison: PublicSurveyMonkeyValueFilterValueComparison
        """
        if self.local_vars_configuration.client_side_validation and value_comparison is None:  # noqa: E501
            raise ValueError("Invalid value for `value_comparison`, must not be `None`")  # noqa: E501

        self._value_comparison = value_comparison

    @property
    def survey_question(self):
        """Gets the survey_question of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The survey_question of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._survey_question

    @survey_question.setter
    def survey_question(self, survey_question):
        """Sets the survey_question of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param survey_question: The survey_question of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type survey_question: str
        """
        if self.local_vars_configuration.client_side_validation and survey_question is None:  # noqa: E501
            raise ValueError("Invalid value for `survey_question`, must not be `None`")  # noqa: E501

        self._survey_question = survey_question

    @property
    def survey_answer_row_id(self):
        """Gets the survey_answer_row_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The survey_answer_row_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._survey_answer_row_id

    @survey_answer_row_id.setter
    def survey_answer_row_id(self, survey_answer_row_id):
        """Sets the survey_answer_row_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param survey_answer_row_id: The survey_answer_row_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type survey_answer_row_id: str
        """

        self._survey_answer_row_id = survey_answer_row_id

    @property
    def survey_answer_col_id(self):
        """Gets the survey_answer_col_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The survey_answer_col_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._survey_answer_col_id

    @survey_answer_col_id.setter
    def survey_answer_col_id(self, survey_answer_col_id):
        """Sets the survey_answer_col_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param survey_answer_col_id: The survey_answer_col_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type survey_answer_col_id: str
        """

        self._survey_answer_col_id = survey_answer_col_id

    @property
    def webinar_id(self):
        """Gets the webinar_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The webinar_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._webinar_id

    @webinar_id.setter
    def webinar_id(self, webinar_id):
        """Sets the webinar_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param webinar_id: The webinar_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type webinar_id: str
        """

        self._webinar_id = webinar_id

    @property
    def click_url(self):
        """Gets the click_url of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The click_url of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._click_url

    @click_url.setter
    def click_url(self, click_url):
        """Sets the click_url of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param click_url: The click_url of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type click_url: str
        """

        self._click_url = click_url

    @property
    def level(self):
        """Gets the level of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The level of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param level: The level of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type level: str
        """
        if self.local_vars_configuration.client_side_validation and level is None:  # noqa: E501
            raise ValueError("Invalid value for `level`, must not be `None`")  # noqa: E501

        self._level = level

    @property
    def app_id(self):
        """Gets the app_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The app_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param app_id: The app_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type app_id: str
        """
        if self.local_vars_configuration.client_side_validation and app_id is None:  # noqa: E501
            raise ValueError("Invalid value for `app_id`, must not be `None`")  # noqa: E501

        self._app_id = app_id

    @property
    def email_id(self):
        """Gets the email_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The email_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param email_id: The email_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type email_id: str
        """
        if self.local_vars_configuration.client_side_validation and email_id is None:  # noqa: E501
            raise ValueError("Invalid value for `email_id`, must not be `None`")  # noqa: E501

        self._email_id = email_id

    @property
    def privacy_name(self):
        """Gets the privacy_name of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The privacy_name of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._privacy_name

    @privacy_name.setter
    def privacy_name(self, privacy_name):
        """Sets the privacy_name of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param privacy_name: The privacy_name of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type privacy_name: str
        """
        if self.local_vars_configuration.client_side_validation and privacy_name is None:  # noqa: E501
            raise ValueError("Invalid value for `privacy_name`, must not be `None`")  # noqa: E501

        self._privacy_name = privacy_name

    @property
    def search_terms(self):
        """Gets the search_terms of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The search_terms of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_terms

    @search_terms.setter
    def search_terms(self, search_terms):
        """Sets the search_terms of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param search_terms: The search_terms of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type search_terms: list[str]
        """
        if self.local_vars_configuration.client_side_validation and search_terms is None:  # noqa: E501
            raise ValueError("Invalid value for `search_terms`, must not be `None`")  # noqa: E501

        self._search_terms = search_terms

    @property
    def entity_type(self):
        """Gets the entity_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The entity_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param entity_type: The entity_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type entity_type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501

        self._entity_type = entity_type

    @property
    def ad_network(self):
        """Gets the ad_network of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The ad_network of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._ad_network

    @ad_network.setter
    def ad_network(self, ad_network):
        """Sets the ad_network of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param ad_network: The ad_network of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type ad_network: str
        """
        if self.local_vars_configuration.client_side_validation and ad_network is None:  # noqa: E501
            raise ValueError("Invalid value for `ad_network`, must not be `None`")  # noqa: E501

        self._ad_network = ad_network

    @property
    def search_term_type(self):
        """Gets the search_term_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The search_term_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._search_term_type

    @search_term_type.setter
    def search_term_type(self, search_term_type):
        """Sets the search_term_type of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param search_term_type: The search_term_type of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type search_term_type: str
        """
        if self.local_vars_configuration.client_side_validation and search_term_type is None:  # noqa: E501
            raise ValueError("Invalid value for `search_term_type`, must not be `None`")  # noqa: E501

        self._search_term_type = search_term_type

    @property
    def metadata(self):
        """Gets the metadata of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The metadata of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: PublicInListFilterMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param metadata: The metadata of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type metadata: PublicInListFilterMetadata
        """

        self._metadata = metadata

    @property
    def property_with_object_id(self):
        """Gets the property_with_object_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The property_with_object_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._property_with_object_id

    @property_with_object_id.setter
    def property_with_object_id(self, property_with_object_id):
        """Sets the property_with_object_id of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param property_with_object_id: The property_with_object_id of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type property_with_object_id: str
        """
        if self.local_vars_configuration.client_side_validation and property_with_object_id is None:  # noqa: E501
            raise ValueError("Invalid value for `property_with_object_id`, must not be `None`")  # noqa: E501

        self._property_with_object_id = property_with_object_id

    @property
    def should_accept(self):
        """Gets the should_accept of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The should_accept of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: bool
        """
        return self._should_accept

    @should_accept.setter
    def should_accept(self, should_accept):
        """Sets the should_accept of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param should_accept: The should_accept of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type should_accept: bool
        """
        if self.local_vars_configuration.client_side_validation and should_accept is None:  # noqa: E501
            raise ValueError("Invalid value for `should_accept`, must not be `None`")  # noqa: E501

        self._should_accept = should_accept

    @property
    def source(self):
        """Gets the source of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501


        :return: The source of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this PublicPropertyAssociationFilterBranchFiltersInner.


        :param source: The source of this PublicPropertyAssociationFilterBranchFiltersInner.  # noqa: E501
        :type source: str
        """

        self._source = source

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicPropertyAssociationFilterBranchFiltersInner):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicPropertyAssociationFilterBranchFiltersInner):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Properties

    All HubSpot objects store data in default and custom properties. These endpoints provide access to read and modify object properties in HubSpot.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.properties.configuration import Configuration


class OptionInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"hidden": "bool", "display_order": "int", "description": "str", "label": "str", "value": "str"}

    attribute_map = {"hidden": "hidden", "display_order": "displayOrder", "description": "description", "label": "label", "value": "value"}

    def __init__(self, hidden=None, display_order=None, description=None, label=None, value=None, local_vars_configuration=None):  # noqa: E501
        """OptionInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hidden = None
        self._display_order = None
        self._description = None
        self._label = None
        self._value = None
        self.discriminator = None

        self.hidden = hidden
        if display_order is not None:
            self.display_order = display_order
        if description is not None:
            self.description = description
        self.label = label
        self.value = value

    @property
    def hidden(self):
        """Gets the hidden of this OptionInput.  # noqa: E501

        Hidden options won't be shown in HubSpot.  # noqa: E501

        :return: The hidden of this OptionInput.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this OptionInput.

        Hidden options won't be shown in HubSpot.  # noqa: E501

        :param hidden: The hidden of this OptionInput.  # noqa: E501
        :type hidden: bool
        """
        if self.local_vars_configuration.client_side_validation and hidden is None:  # noqa: E501
            raise ValueError("Invalid value for `hidden`, must not be `None`")  # noqa: E501

        self._hidden = hidden

    @property
    def display_order(self):
        """Gets the display_order of this OptionInput.  # noqa: E501

        Options are shown in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.  # noqa: E501

        :return: The display_order of this OptionInput.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this OptionInput.

        Options are shown in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.  # noqa: E501

        :param display_order: The display_order of this OptionInput.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def description(self):
        """Gets the description of this OptionInput.  # noqa: E501

        A description of the option.  # noqa: E501

        :return: The description of this OptionInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OptionInput.

        A description of the option.  # noqa: E501

        :param description: The description of this OptionInput.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def label(self):
        """Gets the label of this OptionInput.  # noqa: E501

        A human-readable option label that will be shown in HubSpot.  # noqa: E501

        :return: The label of this OptionInput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this OptionInput.

        A human-readable option label that will be shown in HubSpot.  # noqa: E501

        :param label: The label of this OptionInput.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def value(self):
        """Gets the value of this OptionInput.  # noqa: E501

        The internal value of the option, which must be used when setting the property value through the API.  # noqa: E501

        :return: The value of this OptionInput.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this OptionInput.

        The internal value of the option, which must be used when setting the property value through the API.  # noqa: E501

        :param value: The value of this OptionInput.  # noqa: E501
        :type value: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptionInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.timeline.configuration import Configuration


class TimelineEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "event_template_id": "str",
        "extra_data": "object",
        "timeline_i_frame": "TimelineEventIFrame",
        "domain": "str",
        "tokens": "dict[str, str]",
        "id": "str",
        "utk": "str",
        "email": "str",
        "object_id": "str",
        "timestamp": "datetime",
    }

    attribute_map = {
        "event_template_id": "eventTemplateId",
        "extra_data": "extraData",
        "timeline_i_frame": "timelineIFrame",
        "domain": "domain",
        "tokens": "tokens",
        "id": "id",
        "utk": "utk",
        "email": "email",
        "object_id": "objectId",
        "timestamp": "timestamp",
    }

    def __init__(
        self, event_template_id=None, extra_data=None, timeline_i_frame=None, domain=None, tokens=None, id=None, utk=None, email=None, object_id=None, timestamp=None, local_vars_configuration=None
    ):  # noqa: E501
        """TimelineEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._event_template_id = None
        self._extra_data = None
        self._timeline_i_frame = None
        self._domain = None
        self._tokens = None
        self._id = None
        self._utk = None
        self._email = None
        self._object_id = None
        self._timestamp = None
        self.discriminator = None

        self.event_template_id = event_template_id
        if extra_data is not None:
            self.extra_data = extra_data
        if timeline_i_frame is not None:
            self.timeline_i_frame = timeline_i_frame
        if domain is not None:
            self.domain = domain
        self.tokens = tokens
        if id is not None:
            self.id = id
        if utk is not None:
            self.utk = utk
        if email is not None:
            self.email = email
        if object_id is not None:
            self.object_id = object_id
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def event_template_id(self):
        """Gets the event_template_id of this TimelineEvent.  # noqa: E501

        The event template ID.  # noqa: E501

        :return: The event_template_id of this TimelineEvent.  # noqa: E501
        :rtype: str
        """
        return self._event_template_id

    @event_template_id.setter
    def event_template_id(self, event_template_id):
        """Sets the event_template_id of this TimelineEvent.

        The event template ID.  # noqa: E501

        :param event_template_id: The event_template_id of this TimelineEvent.  # noqa: E501
        :type event_template_id: str
        """
        if self.local_vars_configuration.client_side_validation and event_template_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_template_id`, must not be `None`")  # noqa: E501

        self._event_template_id = event_template_id

    @property
    def extra_data(self):
        """Gets the extra_data of this TimelineEvent.  # noqa: E501

        Additional event-specific data that can be interpreted by the template's markdown.  # noqa: E501

        :return: The extra_data of this TimelineEvent.  # noqa: E501
        :rtype: object
        """
        return self._extra_data

    @extra_data.setter
    def extra_data(self, extra_data):
        """Sets the extra_data of this TimelineEvent.

        Additional event-specific data that can be interpreted by the template's markdown.  # noqa: E501

        :param extra_data: The extra_data of this TimelineEvent.  # noqa: E501
        :type extra_data: object
        """

        self._extra_data = extra_data

    @property
    def timeline_i_frame(self):
        """Gets the timeline_i_frame of this TimelineEvent.  # noqa: E501


        :return: The timeline_i_frame of this TimelineEvent.  # noqa: E501
        :rtype: TimelineEventIFrame
        """
        return self._timeline_i_frame

    @timeline_i_frame.setter
    def timeline_i_frame(self, timeline_i_frame):
        """Sets the timeline_i_frame of this TimelineEvent.


        :param timeline_i_frame: The timeline_i_frame of this TimelineEvent.  # noqa: E501
        :type timeline_i_frame: TimelineEventIFrame
        """

        self._timeline_i_frame = timeline_i_frame

    @property
    def domain(self):
        """Gets the domain of this TimelineEvent.  # noqa: E501

        The event domain (often paired with utk).  # noqa: E501

        :return: The domain of this TimelineEvent.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this TimelineEvent.

        The event domain (often paired with utk).  # noqa: E501

        :param domain: The domain of this TimelineEvent.  # noqa: E501
        :type domain: str
        """

        self._domain = domain

    @property
    def tokens(self):
        """Gets the tokens of this TimelineEvent.  # noqa: E501

        A collection of token keys and values associated with the template tokens.  # noqa: E501

        :return: The tokens of this TimelineEvent.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._tokens

    @tokens.setter
    def tokens(self, tokens):
        """Sets the tokens of this TimelineEvent.

        A collection of token keys and values associated with the template tokens.  # noqa: E501

        :param tokens: The tokens of this TimelineEvent.  # noqa: E501
        :type tokens: dict[str, str]
        """
        if self.local_vars_configuration.client_side_validation and tokens is None:  # noqa: E501
            raise ValueError("Invalid value for `tokens`, must not be `None`")  # noqa: E501

        self._tokens = tokens

    @property
    def id(self):
        """Gets the id of this TimelineEvent.  # noqa: E501

        Identifier for the event. This is optional, and we recommend you do not pass this in. We will create one for you if you omit this. You can also use `{{uuid}}` anywhere in the ID to generate a unique string, guaranteeing uniqueness.  # noqa: E501

        :return: The id of this TimelineEvent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TimelineEvent.

        Identifier for the event. This is optional, and we recommend you do not pass this in. We will create one for you if you omit this. You can also use `{{uuid}}` anywhere in the ID to generate a unique string, guaranteeing uniqueness.  # noqa: E501

        :param id: The id of this TimelineEvent.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def utk(self):
        """Gets the utk of this TimelineEvent.  # noqa: E501

        Use the `utk` parameter to associate an event with a contact by `usertoken`. This is recommended if you don't know a user's email, but have an identifying user token in your cookie.  # noqa: E501

        :return: The utk of this TimelineEvent.  # noqa: E501
        :rtype: str
        """
        return self._utk

    @utk.setter
    def utk(self, utk):
        """Sets the utk of this TimelineEvent.

        Use the `utk` parameter to associate an event with a contact by `usertoken`. This is recommended if you don't know a user's email, but have an identifying user token in your cookie.  # noqa: E501

        :param utk: The utk of this TimelineEvent.  # noqa: E501
        :type utk: str
        """

        self._utk = utk

    @property
    def email(self):
        """Gets the email of this TimelineEvent.  # noqa: E501

        The email address used for contact-specific events. This can be used to identify existing contacts, create new ones, or change the email for an existing contact (if paired with the `objectId`).  # noqa: E501

        :return: The email of this TimelineEvent.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this TimelineEvent.

        The email address used for contact-specific events. This can be used to identify existing contacts, create new ones, or change the email for an existing contact (if paired with the `objectId`).  # noqa: E501

        :param email: The email of this TimelineEvent.  # noqa: E501
        :type email: str
        """

        self._email = email

    @property
    def object_id(self):
        """Gets the object_id of this TimelineEvent.  # noqa: E501

        The CRM object identifier. This is required for every event other than contacts (where utk or email can be used).  # noqa: E501

        :return: The object_id of this TimelineEvent.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this TimelineEvent.

        The CRM object identifier. This is required for every event other than contacts (where utk or email can be used).  # noqa: E501

        :param object_id: The object_id of this TimelineEvent.  # noqa: E501
        :type object_id: str
        """

        self._object_id = object_id

    @property
    def timestamp(self):
        """Gets the timestamp of this TimelineEvent.  # noqa: E501

        The time the event occurred. If not passed in, the curren time will be assumed. This is used to determine where an event is shown on a CRM object's timeline.  # noqa: E501

        :return: The timestamp of this TimelineEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this TimelineEvent.

        The time the event occurred. If not passed in, the curren time will be assumed. This is used to determine where an event is shown on a CRM object's timeline.  # noqa: E501

        :param timestamp: The timestamp of this TimelineEvent.  # noqa: E501
        :type timestamp: datetime
        """

        self._timestamp = timestamp

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimelineEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TimelineEvent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Transactional Single Send

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.transactional.configuration import Configuration


class SmtpApiTokenView(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"created_at": "datetime", "password": "str", "created_by": "str", "create_contact": "bool", "id": "str", "email_campaign_id": "str", "campaign_name": "str"}

    attribute_map = {
        "created_at": "createdAt",
        "password": "password",
        "created_by": "createdBy",
        "create_contact": "createContact",
        "id": "id",
        "email_campaign_id": "emailCampaignId",
        "campaign_name": "campaignName",
    }

    def __init__(self, created_at=None, password=None, created_by=None, create_contact=None, id=None, email_campaign_id=None, campaign_name=None, local_vars_configuration=None):  # noqa: E501
        """SmtpApiTokenView - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._password = None
        self._created_by = None
        self._create_contact = None
        self._id = None
        self._email_campaign_id = None
        self._campaign_name = None
        self.discriminator = None

        self.created_at = created_at
        if password is not None:
            self.password = password
        self.created_by = created_by
        self.create_contact = create_contact
        self.id = id
        self.email_campaign_id = email_campaign_id
        self.campaign_name = campaign_name

    @property
    def created_at(self):
        """Gets the created_at of this SmtpApiTokenView.  # noqa: E501

        Timestamp generated when a token is created.  # noqa: E501

        :return: The created_at of this SmtpApiTokenView.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SmtpApiTokenView.

        Timestamp generated when a token is created.  # noqa: E501

        :param created_at: The created_at of this SmtpApiTokenView.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def password(self):
        """Gets the password of this SmtpApiTokenView.  # noqa: E501

        Password used to log into the HubSpot SMTP server.  # noqa: E501

        :return: The password of this SmtpApiTokenView.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this SmtpApiTokenView.

        Password used to log into the HubSpot SMTP server.  # noqa: E501

        :param password: The password of this SmtpApiTokenView.  # noqa: E501
        :type password: str
        """

        self._password = password

    @property
    def created_by(self):
        """Gets the created_by of this SmtpApiTokenView.  # noqa: E501

        Email address of the user that sent the token creation request.  # noqa: E501

        :return: The created_by of this SmtpApiTokenView.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this SmtpApiTokenView.

        Email address of the user that sent the token creation request.  # noqa: E501

        :param created_by: The created_by of this SmtpApiTokenView.  # noqa: E501
        :type created_by: str
        """
        if self.local_vars_configuration.client_side_validation and created_by is None:  # noqa: E501
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def create_contact(self):
        """Gets the create_contact of this SmtpApiTokenView.  # noqa: E501

        Indicates whether a contact should be created for email recipients.  # noqa: E501

        :return: The create_contact of this SmtpApiTokenView.  # noqa: E501
        :rtype: bool
        """
        return self._create_contact

    @create_contact.setter
    def create_contact(self, create_contact):
        """Sets the create_contact of this SmtpApiTokenView.

        Indicates whether a contact should be created for email recipients.  # noqa: E501

        :param create_contact: The create_contact of this SmtpApiTokenView.  # noqa: E501
        :type create_contact: bool
        """
        if self.local_vars_configuration.client_side_validation and create_contact is None:  # noqa: E501
            raise ValueError("Invalid value for `create_contact`, must not be `None`")  # noqa: E501

        self._create_contact = create_contact

    @property
    def id(self):
        """Gets the id of this SmtpApiTokenView.  # noqa: E501

        User name to log into the HubSpot SMTP server.  # noqa: E501

        :return: The id of this SmtpApiTokenView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SmtpApiTokenView.

        User name to log into the HubSpot SMTP server.  # noqa: E501

        :param id: The id of this SmtpApiTokenView.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def email_campaign_id(self):
        """Gets the email_campaign_id of this SmtpApiTokenView.  # noqa: E501

        Identifier assigned to the campaign provided in the token creation request.  # noqa: E501

        :return: The email_campaign_id of this SmtpApiTokenView.  # noqa: E501
        :rtype: str
        """
        return self._email_campaign_id

    @email_campaign_id.setter
    def email_campaign_id(self, email_campaign_id):
        """Sets the email_campaign_id of this SmtpApiTokenView.

        Identifier assigned to the campaign provided in the token creation request.  # noqa: E501

        :param email_campaign_id: The email_campaign_id of this SmtpApiTokenView.  # noqa: E501
        :type email_campaign_id: str
        """
        if self.local_vars_configuration.client_side_validation and email_campaign_id is None:  # noqa: E501
            raise ValueError("Invalid value for `email_campaign_id`, must not be `None`")  # noqa: E501

        self._email_campaign_id = email_campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this SmtpApiTokenView.  # noqa: E501

        A name for the campaign tied to the token.  # noqa: E501

        :return: The campaign_name of this SmtpApiTokenView.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this SmtpApiTokenView.

        A name for the campaign tied to the token.  # noqa: E501

        :param campaign_name: The campaign_name of this SmtpApiTokenView.  # noqa: E501
        :type campaign_name: str
        """
        if self.local_vars_configuration.client_side_validation and campaign_name is None:  # noqa: E501
            raise ValueError("Invalid value for `campaign_name`, must not be `None`")  # noqa: E501

        self._campaign_name = campaign_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SmtpApiTokenView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SmtpApiTokenView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    CMS Source Code

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.cms.source_code.api.content_api import ContentApi
from hubspot.cms.source_code.api.extract_api import ExtractApi
from hubspot.cms.source_code.api.metadata_api import MetadataApi
from hubspot.cms.source_code.api.validation_api import ValidationApi

# import ApiClient
from hubspot.cms.source_code.api_client import ApiClient
from hubspot.cms.source_code.configuration import Configuration
from hubspot.cms.source_code.exceptions import OpenApiException
from hubspot.cms.source_code.exceptions import ApiTypeError
from hubspot.cms.source_code.exceptions import ApiValueError
from hubspot.cms.source_code.exceptions import ApiKeyError
from hubspot.cms.source_code.exceptions import ApiAttributeError
from hubspot.cms.source_code.exceptions import ApiException

# import models into sdk package
from hubspot.cms.source_code.models.action_response import ActionResponse
from hubspot.cms.source_code.models.asset_file_metadata import AssetFileMetadata
from hubspot.cms.source_code.models.error import Error
from hubspot.cms.source_code.models.error_detail import ErrorDetail
from hubspot.cms.source_code.models.file_extract_request import FileExtractRequest
from hubspot.cms.source_code.models.task_locator import TaskLocator



# coding: utf-8

# flake8: noqa
"""
    Conversations Inbox & Messages

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from hubspot.conversations.conversations.models.agent_actor import AgentActor
from hubspot.conversations.conversations.models.batch_input_string import BatchInputString
from hubspot.conversations.conversations.models.batch_response_public_actor import BatchResponsePublicActor
from hubspot.conversations.conversations.models.batch_response_public_actor_with_errors import BatchResponsePublicActorWithErrors
from hubspot.conversations.conversations.models.bot_actor import BotActor
from hubspot.conversations.conversations.models.collection_response_public_message_forward_paging import CollectionResponsePublicMessageForwardPaging
from hubspot.conversations.conversations.models.collection_response_public_thread_forward_paging import CollectionResponsePublicThreadForwardPaging
from hubspot.conversations.conversations.models.collection_response_with_total_public_channel_account_forward_paging import CollectionResponseWithTotalPublicChannelAccountForwardPaging
from hubspot.conversations.conversations.models.collection_response_with_total_public_channel_forward_paging import CollectionResponseWithTotalPublicChannelForwardPaging
from hubspot.conversations.conversations.models.collection_response_with_total_public_inbox_forward_paging import CollectionResponseWithTotalPublicInboxForwardPaging
from hubspot.conversations.conversations.models.contact_address import ContactAddress
from hubspot.conversations.conversations.models.contact_email import ContactEmail
from hubspot.conversations.conversations.models.contact_name import ContactName
from hubspot.conversations.conversations.models.contact_org import ContactOrg
from hubspot.conversations.conversations.models.contact_phone import ContactPhone
from hubspot.conversations.conversations.models.contact_profile import ContactProfile
from hubspot.conversations.conversations.models.contact_url import ContactUrl
from hubspot.conversations.conversations.models.email_actor import EmailActor
from hubspot.conversations.conversations.models.error import Error
from hubspot.conversations.conversations.models.error_detail import ErrorDetail
from hubspot.conversations.conversations.models.forward_paging import ForwardPaging
from hubspot.conversations.conversations.models.integrator_actor import IntegratorActor
from hubspot.conversations.conversations.models.next_page import NextPage
from hubspot.conversations.conversations.models.public_actor import PublicActor
from hubspot.conversations.conversations.models.public_actor_base import PublicActorBase
from hubspot.conversations.conversations.models.public_assignment_message import PublicAssignmentMessage
from hubspot.conversations.conversations.models.public_channel import PublicChannel
from hubspot.conversations.conversations.models.public_channel_account import PublicChannelAccount
from hubspot.conversations.conversations.models.public_client import PublicClient
from hubspot.conversations.conversations.models.public_comment import PublicComment
from hubspot.conversations.conversations.models.public_comment_all_of_attachments import PublicCommentAllOfAttachments
from hubspot.conversations.conversations.models.public_comment_egg import PublicCommentEgg
from hubspot.conversations.conversations.models.public_comment_egg_attachments_inner import PublicCommentEggAttachmentsInner
from hubspot.conversations.conversations.models.public_contact import PublicContact
from hubspot.conversations.conversations.models.public_conversations_message import PublicConversationsMessage
from hubspot.conversations.conversations.models.public_conversations_message_all_of_attachments import PublicConversationsMessageAllOfAttachments
from hubspot.conversations.conversations.models.public_conversations_message_egg import PublicConversationsMessageEgg
from hubspot.conversations.conversations.models.public_delivery_identifier import PublicDeliveryIdentifier
from hubspot.conversations.conversations.models.public_file import PublicFile
from hubspot.conversations.conversations.models.public_file_egg import PublicFileEgg
from hubspot.conversations.conversations.models.public_inbox import PublicInbox
from hubspot.conversations.conversations.models.public_location import PublicLocation
from hubspot.conversations.conversations.models.public_message import PublicMessage
from hubspot.conversations.conversations.models.public_message_base import PublicMessageBase
from hubspot.conversations.conversations.models.public_message_content import PublicMessageContent
from hubspot.conversations.conversations.models.public_message_egg import PublicMessageEgg
from hubspot.conversations.conversations.models.public_message_failure_details import PublicMessageFailureDetails
from hubspot.conversations.conversations.models.public_message_header import PublicMessageHeader
from hubspot.conversations.conversations.models.public_message_status import PublicMessageStatus
from hubspot.conversations.conversations.models.public_quick_replies import PublicQuickReplies
from hubspot.conversations.conversations.models.public_quick_replies_egg import PublicQuickRepliesEgg
from hubspot.conversations.conversations.models.public_recipient import PublicRecipient
from hubspot.conversations.conversations.models.public_recipient_egg import PublicRecipientEgg
from hubspot.conversations.conversations.models.public_sender import PublicSender
from hubspot.conversations.conversations.models.public_thread import PublicThread
from hubspot.conversations.conversations.models.public_thread_associations import PublicThreadAssociations
from hubspot.conversations.conversations.models.public_thread_inbox_change import PublicThreadInboxChange
from hubspot.conversations.conversations.models.public_thread_status_change import PublicThreadStatusChange
from hubspot.conversations.conversations.models.public_thread_update_request import PublicThreadUpdateRequest
from hubspot.conversations.conversations.models.public_unsupported_content import PublicUnsupportedContent
from hubspot.conversations.conversations.models.public_welcome_message import PublicWelcomeMessage
from hubspot.conversations.conversations.models.public_whats_app_template_metadata import PublicWhatsAppTemplateMetadata
from hubspot.conversations.conversations.models.quick_reply import QuickReply
from hubspot.conversations.conversations.models.standard_error import StandardError
from hubspot.conversations.conversations.models.system_actor import SystemActor
from hubspot.conversations.conversations.models.visitor_actor import VisitorActor



# coding: utf-8

"""
    Posts

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.cms.blogs.blog_posts.api_client import ApiClient
from hubspot.cms.blogs.blog_posts.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class BatchApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, batch_input_string, **kwargs):  # noqa: E501
        """Delete a batch of blog posts  # noqa: E501

        Delete a blog post by ID.  Note: This is not the same as the in-app `archive` function. To perform a dashboard `archive` send an normal update with the `archivedInDashboard` field set to `true`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(batch_input_string, async_req=True)
        >>> result = thread.get()

        :param batch_input_string: The JSON array of Blog Post ids. (required)
        :type batch_input_string: BatchInputString
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(batch_input_string, **kwargs)  # noqa: E501

    def archive_with_http_info(self, batch_input_string, **kwargs):  # noqa: E501
        """Delete a batch of blog posts  # noqa: E501

        Delete a blog post by ID.  Note: This is not the same as the in-app `archive` function. To perform a dashboard `archive` send an normal update with the `archivedInDashboard` field set to `true`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(batch_input_string, async_req=True)
        >>> result = thread.get()

        :param batch_input_string: The JSON array of Blog Post ids. (required)
        :type batch_input_string: BatchInputString
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["batch_input_string"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_string' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_string") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_string` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_string" in local_var_params:
            body_params = local_var_params["batch_input_string"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/batch/archive",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, batch_input_blog_post, **kwargs):  # noqa: E501
        """Create a batch of blog posts  # noqa: E501

        Create a batch of blog posts, specifying their content in the request body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(batch_input_blog_post, async_req=True)
        >>> result = thread.get()

        :param batch_input_blog_post: The JSON array of new Blog Posts to create. (required)
        :type batch_input_blog_post: BatchInputBlogPost
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseBlogPost
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(batch_input_blog_post, **kwargs)  # noqa: E501

    def create_with_http_info(self, batch_input_blog_post, **kwargs):  # noqa: E501
        """Create a batch of blog posts  # noqa: E501

        Create a batch of blog posts, specifying their content in the request body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(batch_input_blog_post, async_req=True)
        >>> result = thread.get()

        :param batch_input_blog_post: The JSON array of new Blog Posts to create. (required)
        :type batch_input_blog_post: BatchInputBlogPost
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseBlogPost, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_input_blog_post"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_blog_post' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_blog_post") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_blog_post` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_blog_post" in local_var_params:
            body_params = local_var_params["batch_input_blog_post"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "BatchResponseBlogPost",
            207: "BatchResponseBlogPostWithErrors",
        }

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/batch/create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def read(self, batch_input_string, **kwargs):  # noqa: E501
        """Retrieve a batch of Blog Posts  # noqa: E501

        Retrieve a batch of blog posts by ID. identified in the request body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.read(batch_input_string, async_req=True)
        >>> result = thread.get()

        :param batch_input_string: The JSON array of Blog Post ids. (required)
        :type batch_input_string: BatchInputString
        :param archived: Specifies whether to return deleted blog posts Defaults to `false`.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseBlogPost
        """
        kwargs["_return_http_data_only"] = True
        return self.read_with_http_info(batch_input_string, **kwargs)  # noqa: E501

    def read_with_http_info(self, batch_input_string, **kwargs):  # noqa: E501
        """Retrieve a batch of Blog Posts  # noqa: E501

        Retrieve a batch of blog posts by ID. identified in the request body.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.read_with_http_info(batch_input_string, async_req=True)
        >>> result = thread.get()

        :param batch_input_string: The JSON array of Blog Post ids. (required)
        :type batch_input_string: BatchInputString
        :param archived: Specifies whether to return deleted blog posts Defaults to `false`.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseBlogPost, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_input_string", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method read" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_string' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_string") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_string` when calling `read`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_string" in local_var_params:
            body_params = local_var_params["batch_input_string"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseBlogPost",
            207: "BatchResponseBlogPostWithErrors",
        }

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/batch/read",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, batch_input_json_node, **kwargs):  # noqa: E501
        """Update a batch of Blog Posts  # noqa: E501

        Update a batch of blog posts.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(batch_input_json_node, async_req=True)
        >>> result = thread.get()

        :param batch_input_json_node: A JSON array of the JSON representations of the updated Blog Posts. (required)
        :type batch_input_json_node: BatchInputJsonNode
        :param archived: Specifies whether to update deleted Blog Posts. Defaults to `false`.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseBlogPost
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(batch_input_json_node, **kwargs)  # noqa: E501

    def update_with_http_info(self, batch_input_json_node, **kwargs):  # noqa: E501
        """Update a batch of Blog Posts  # noqa: E501

        Update a batch of blog posts.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(batch_input_json_node, async_req=True)
        >>> result = thread.get()

        :param batch_input_json_node: A JSON array of the JSON representations of the updated Blog Posts. (required)
        :type batch_input_json_node: BatchInputJsonNode
        :param archived: Specifies whether to update deleted Blog Posts. Defaults to `false`.
        :type archived: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseBlogPost, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["batch_input_json_node", "archived"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'batch_input_json_node' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_json_node") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_json_node` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("archived") is not None:  # noqa: E501
            query_params.append(("archived", local_var_params["archived"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_json_node" in local_var_params:
            body_params = local_var_params["batch_input_json_node"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseBlogPost",
            207: "BatchResponseBlogPostWithErrors",
        }

        return self.api_client.call_api(
            "/cms/v3/blogs/posts/batch/update",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

# flake8: noqa

"""
    Events Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.events.api.events_api import EventsApi

# import ApiClient
from hubspot.events.api_client import ApiClient
from hubspot.events.configuration import Configuration
from hubspot.events.exceptions import OpenApiException
from hubspot.events.exceptions import ApiTypeError
from hubspot.events.exceptions import ApiValueError
from hubspot.events.exceptions import ApiKeyError
from hubspot.events.exceptions import ApiAttributeError
from hubspot.events.exceptions import ApiException

# import models into sdk package
from hubspot.events.models.collection_response_external_unified_event import CollectionResponseExternalUnifiedEvent
from hubspot.events.models.error import Error
from hubspot.events.models.error_detail import ErrorDetail
from hubspot.events.models.external_unified_event import ExternalUnifiedEvent
from hubspot.events.models.next_page import NextPage
from hubspot.events.models.paging import Paging
from hubspot.events.models.previous_page import PreviousPage
from hubspot.events.models.visible_external_event_type_names import VisibleExternalEventTypeNames



# coding: utf-8

"""
    Transactional Single Send

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.marketing.transactional.api_client import ApiClient
from hubspot.marketing.transactional.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class SingleSendApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def send_email(self, public_single_send_request_egg, **kwargs):  # noqa: E501
        """Send a single transactional email asynchronously.  # noqa: E501

        Asynchronously send a transactional email. Returns the status of the email send with a statusId that can be used to continuously query for the status using the Email Send Status API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_email(public_single_send_request_egg, async_req=True)
        >>> result = thread.get()

        :param public_single_send_request_egg: A request object describing the email to send. (required)
        :type public_single_send_request_egg: PublicSingleSendRequestEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: EmailSendStatusView
        """
        kwargs["_return_http_data_only"] = True
        return self.send_email_with_http_info(public_single_send_request_egg, **kwargs)  # noqa: E501

    def send_email_with_http_info(self, public_single_send_request_egg, **kwargs):  # noqa: E501
        """Send a single transactional email asynchronously.  # noqa: E501

        Asynchronously send a transactional email. Returns the status of the email send with a statusId that can be used to continuously query for the status using the Email Send Status API.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_email_with_http_info(public_single_send_request_egg, async_req=True)
        >>> result = thread.get()

        :param public_single_send_request_egg: A request object describing the email to send. (required)
        :type public_single_send_request_egg: PublicSingleSendRequestEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(EmailSendStatusView, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["public_single_send_request_egg"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method send_email" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'public_single_send_request_egg' is set
        if self.api_client.client_side_validation and local_var_params.get("public_single_send_request_egg") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `public_single_send_request_egg` when calling `send_email`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "public_single_send_request_egg" in local_var_params:
            body_params = local_var_params["public_single_send_request_egg"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "EmailSendStatusView",
        }

        return self.api_client.call_api(
            "/marketing/v3/transactional/single-email/send",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class BatchResponseSimplePublicObject(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"completed_at": "datetime", "requested_at": "datetime", "started_at": "datetime", "links": "dict[str, str]", "results": "list[SimplePublicObject]", "status": "str"}

    attribute_map = {"completed_at": "completedAt", "requested_at": "requestedAt", "started_at": "startedAt", "links": "links", "results": "results", "status": "status"}

    def __init__(self, completed_at=None, requested_at=None, started_at=None, links=None, results=None, status=None, local_vars_configuration=None):  # noqa: E501
        """BatchResponseSimplePublicObject - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._completed_at = None
        self._requested_at = None
        self._started_at = None
        self._links = None
        self._results = None
        self._status = None
        self.discriminator = None

        self.completed_at = completed_at
        if requested_at is not None:
            self.requested_at = requested_at
        self.started_at = started_at
        if links is not None:
            self.links = links
        self.results = results
        self.status = status

    @property
    def completed_at(self):
        """Gets the completed_at of this BatchResponseSimplePublicObject.  # noqa: E501


        :return: The completed_at of this BatchResponseSimplePublicObject.  # noqa: E501
        :rtype: datetime
        """
        return self._completed_at

    @completed_at.setter
    def completed_at(self, completed_at):
        """Sets the completed_at of this BatchResponseSimplePublicObject.


        :param completed_at: The completed_at of this BatchResponseSimplePublicObject.  # noqa: E501
        :type completed_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and completed_at is None:  # noqa: E501
            raise ValueError("Invalid value for `completed_at`, must not be `None`")  # noqa: E501

        self._completed_at = completed_at

    @property
    def requested_at(self):
        """Gets the requested_at of this BatchResponseSimplePublicObject.  # noqa: E501


        :return: The requested_at of this BatchResponseSimplePublicObject.  # noqa: E501
        :rtype: datetime
        """
        return self._requested_at

    @requested_at.setter
    def requested_at(self, requested_at):
        """Sets the requested_at of this BatchResponseSimplePublicObject.


        :param requested_at: The requested_at of this BatchResponseSimplePublicObject.  # noqa: E501
        :type requested_at: datetime
        """

        self._requested_at = requested_at

    @property
    def started_at(self):
        """Gets the started_at of this BatchResponseSimplePublicObject.  # noqa: E501


        :return: The started_at of this BatchResponseSimplePublicObject.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this BatchResponseSimplePublicObject.


        :param started_at: The started_at of this BatchResponseSimplePublicObject.  # noqa: E501
        :type started_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and started_at is None:  # noqa: E501
            raise ValueError("Invalid value for `started_at`, must not be `None`")  # noqa: E501

        self._started_at = started_at

    @property
    def links(self):
        """Gets the links of this BatchResponseSimplePublicObject.  # noqa: E501


        :return: The links of this BatchResponseSimplePublicObject.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this BatchResponseSimplePublicObject.


        :param links: The links of this BatchResponseSimplePublicObject.  # noqa: E501
        :type links: dict[str, str]
        """

        self._links = links

    @property
    def results(self):
        """Gets the results of this BatchResponseSimplePublicObject.  # noqa: E501


        :return: The results of this BatchResponseSimplePublicObject.  # noqa: E501
        :rtype: list[SimplePublicObject]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this BatchResponseSimplePublicObject.


        :param results: The results of this BatchResponseSimplePublicObject.  # noqa: E501
        :type results: list[SimplePublicObject]
        """
        if self.local_vars_configuration.client_side_validation and results is None:  # noqa: E501
            raise ValueError("Invalid value for `results`, must not be `None`")  # noqa: E501

        self._results = results

    @property
    def status(self):
        """Gets the status of this BatchResponseSimplePublicObject.  # noqa: E501


        :return: The status of this BatchResponseSimplePublicObject.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BatchResponseSimplePublicObject.


        :param status: The status of this BatchResponseSimplePublicObject.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "PROCESSING", "CANCELED", "COMPLETE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values))  # noqa: E501

        self._status = status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchResponseSimplePublicObject):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatchResponseSimplePublicObject):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.crm.extensions.calling as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):

    @property
    def channel_connection_settings_api(self) -> api_client.ChannelConnectionSettingsApi:
        return self._configure_api_client(api_client, "ChannelConnectionSettingsApi")

    @property
    def recording_settings_api(self) -> api_client.RecordingSettingsApi:
        return self._configure_api_client(api_client, "RecordingSettingsApi")

    @property
    def settings_api(self) -> api_client.SettingsApi:
        return self._configure_api_client(api_client, "SettingsApi")



# coding: utf-8

"""
    Webhooks Webhooks

    Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.webhooks.configuration import Configuration


class SubscriptionResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"created_at": "datetime", "object_type_id": "str", "property_name": "str", "active": "bool", "event_type": "str", "id": "str", "updated_at": "datetime"}

    attribute_map = {"created_at": "createdAt", "object_type_id": "objectTypeId", "property_name": "propertyName", "active": "active", "event_type": "eventType", "id": "id", "updated_at": "updatedAt"}

    def __init__(self, created_at=None, object_type_id=None, property_name=None, active=None, event_type=None, id=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """SubscriptionResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._object_type_id = None
        self._property_name = None
        self._active = None
        self._event_type = None
        self._id = None
        self._updated_at = None
        self.discriminator = None

        self.created_at = created_at
        if object_type_id is not None:
            self.object_type_id = object_type_id
        if property_name is not None:
            self.property_name = property_name
        self.active = active
        self.event_type = event_type
        self.id = id
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this SubscriptionResponse.  # noqa: E501

        When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :return: The created_at of this SubscriptionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SubscriptionResponse.

        When this subscription was created. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :param created_at: The created_at of this SubscriptionResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def object_type_id(self):
        """Gets the object_type_id of this SubscriptionResponse.  # noqa: E501


        :return: The object_type_id of this SubscriptionResponse.  # noqa: E501
        :rtype: str
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this SubscriptionResponse.


        :param object_type_id: The object_type_id of this SubscriptionResponse.  # noqa: E501
        :type object_type_id: str
        """

        self._object_type_id = object_type_id

    @property
    def property_name(self):
        """Gets the property_name of this SubscriptionResponse.  # noqa: E501

        The internal name of the property being monitored for changes. Only applies when `eventType` is `propertyChange`.  # noqa: E501

        :return: The property_name of this SubscriptionResponse.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this SubscriptionResponse.

        The internal name of the property being monitored for changes. Only applies when `eventType` is `propertyChange`.  # noqa: E501

        :param property_name: The property_name of this SubscriptionResponse.  # noqa: E501
        :type property_name: str
        """

        self._property_name = property_name

    @property
    def active(self):
        """Gets the active of this SubscriptionResponse.  # noqa: E501

        Determines if the subscription is active or paused.  # noqa: E501

        :return: The active of this SubscriptionResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this SubscriptionResponse.

        Determines if the subscription is active or paused.  # noqa: E501

        :param active: The active of this SubscriptionResponse.  # noqa: E501
        :type active: bool
        """
        if self.local_vars_configuration.client_side_validation and active is None:  # noqa: E501
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def event_type(self):
        """Gets the event_type of this SubscriptionResponse.  # noqa: E501

        Type of event to listen for. Can be one of `create`, `delete`, `deletedForPrivacy`, or `propertyChange`.  # noqa: E501

        :return: The event_type of this SubscriptionResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this SubscriptionResponse.

        Type of event to listen for. Can be one of `create`, `delete`, `deletedForPrivacy`, or `propertyChange`.  # noqa: E501

        :param event_type: The event_type of this SubscriptionResponse.  # noqa: E501
        :type event_type: str
        """
        if self.local_vars_configuration.client_side_validation and event_type is None:  # noqa: E501
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501
        allowed_values = [
            "contact.propertyChange",
            "company.propertyChange",
            "deal.propertyChange",
            "ticket.propertyChange",
            "product.propertyChange",
            "line_item.propertyChange",
            "contact.creation",
            "contact.deletion",
            "contact.privacyDeletion",
            "company.creation",
            "company.deletion",
            "deal.creation",
            "deal.deletion",
            "ticket.creation",
            "ticket.deletion",
            "product.creation",
            "product.deletion",
            "line_item.creation",
            "line_item.deletion",
            "conversation.creation",
            "conversation.deletion",
            "conversation.newMessage",
            "conversation.privacyDeletion",
            "conversation.propertyChange",
            "contact.merge",
            "company.merge",
            "deal.merge",
            "ticket.merge",
            "product.merge",
            "line_item.merge",
            "contact.restore",
            "company.restore",
            "deal.restore",
            "ticket.restore",
            "product.restore",
            "line_item.restore",
            "contact.associationChange",
            "company.associationChange",
            "deal.associationChange",
            "ticket.associationChange",
            "line_item.associationChange",
            "object.propertyChange",
            "object.creation",
            "object.deletion",
            "object.merge",
            "object.restore",
            "object.associationChange",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and event_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `event_type` ({0}), must be one of {1}".format(event_type, allowed_values))  # noqa: E501

        self._event_type = event_type

    @property
    def id(self):
        """Gets the id of this SubscriptionResponse.  # noqa: E501

        The unique ID of the subscription.  # noqa: E501

        :return: The id of this SubscriptionResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionResponse.

        The unique ID of the subscription.  # noqa: E501

        :param id: The id of this SubscriptionResponse.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def updated_at(self):
        """Gets the updated_at of this SubscriptionResponse.  # noqa: E501

        When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :return: The updated_at of this SubscriptionResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SubscriptionResponse.

        When this subscription was last updated. Formatted as milliseconds from the [Unix epoch](#).  # noqa: E501

        :param updated_at: The updated_at of this SubscriptionResponse.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubscriptionResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicNumOccurrencesRefineBy(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"max_occurrences": "int", "type": "str", "min_occurrences": "int"}

    attribute_map = {"max_occurrences": "maxOccurrences", "type": "type", "min_occurrences": "minOccurrences"}

    def __init__(self, max_occurrences=None, type="NUM_OCCURRENCES", min_occurrences=None, local_vars_configuration=None):  # noqa: E501
        """PublicNumOccurrencesRefineBy - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._max_occurrences = None
        self._type = None
        self._min_occurrences = None
        self.discriminator = None

        if max_occurrences is not None:
            self.max_occurrences = max_occurrences
        self.type = type
        if min_occurrences is not None:
            self.min_occurrences = min_occurrences

    @property
    def max_occurrences(self):
        """Gets the max_occurrences of this PublicNumOccurrencesRefineBy.  # noqa: E501


        :return: The max_occurrences of this PublicNumOccurrencesRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._max_occurrences

    @max_occurrences.setter
    def max_occurrences(self, max_occurrences):
        """Sets the max_occurrences of this PublicNumOccurrencesRefineBy.


        :param max_occurrences: The max_occurrences of this PublicNumOccurrencesRefineBy.  # noqa: E501
        :type max_occurrences: int
        """

        self._max_occurrences = max_occurrences

    @property
    def type(self):
        """Gets the type of this PublicNumOccurrencesRefineBy.  # noqa: E501


        :return: The type of this PublicNumOccurrencesRefineBy.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicNumOccurrencesRefineBy.


        :param type: The type of this PublicNumOccurrencesRefineBy.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["NUM_OCCURRENCES"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def min_occurrences(self):
        """Gets the min_occurrences of this PublicNumOccurrencesRefineBy.  # noqa: E501


        :return: The min_occurrences of this PublicNumOccurrencesRefineBy.  # noqa: E501
        :rtype: int
        """
        return self._min_occurrences

    @min_occurrences.setter
    def min_occurrences(self, min_occurrences):
        """Sets the min_occurrences of this PublicNumOccurrencesRefineBy.


        :param min_occurrences: The min_occurrences of this PublicNumOccurrencesRefineBy.  # noqa: E501
        :type min_occurrences: int
        """

        self._min_occurrences = min_occurrences

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicNumOccurrencesRefineBy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicNumOccurrencesRefineBy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Conversations Inbox & Messages

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from hubspot.conversations.conversations.models.public_client import PublicClient
from hubspot.conversations.conversations.models.public_recipient import PublicRecipient
from hubspot.conversations.conversations.models.public_sender import PublicSender
from typing import Optional, Set
from typing_extensions import Self

class PublicAssignmentMessage(BaseModel):
    """
    PublicAssignmentMessage
    """ # noqa: E501
    id: StrictStr
    conversations_thread_id: StrictStr = Field(alias="conversationsThreadId")
    created_at: datetime = Field(alias="createdAt")
    updated_at: Optional[datetime] = Field(default=None, alias="updatedAt")
    created_by: StrictStr = Field(alias="createdBy")
    client: PublicClient
    senders: List[PublicSender]
    recipients: List[PublicRecipient]
    archived: StrictBool
    type: StrictStr
    assigned_to: Optional[StrictStr] = Field(default=None, alias="assignedTo")
    assigned_from: Optional[StrictStr] = Field(default=None, alias="assignedFrom")
    __properties: ClassVar[List[str]] = ["id", "conversationsThreadId", "createdAt", "updatedAt", "createdBy", "client", "senders", "recipients", "archived", "type", "assignedTo", "assignedFrom"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['ASSIGNMENT']):
            raise ValueError("must be one of enum values ('ASSIGNMENT')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PublicAssignmentMessage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of client
        if self.client:
            _dict['client'] = self.client.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in senders (list)
        _items = []
        if self.senders:
            for _item_senders in self.senders:
                if _item_senders:
                    _items.append(_item_senders.to_dict())
            _dict['senders'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in recipients (list)
        _items = []
        if self.recipients:
            for _item_recipients in self.recipients:
                if _item_recipients:
                    _items.append(_item_recipients.to_dict())
            _dict['recipients'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PublicAssignmentMessage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "conversationsThreadId": obj.get("conversationsThreadId"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "createdBy": obj.get("createdBy"),
            "client": PublicClient.from_dict(obj["client"]) if obj.get("client") is not None else None,
            "senders": [PublicSender.from_dict(_item) for _item in obj["senders"]] if obj.get("senders") is not None else None,
            "recipients": [PublicRecipient.from_dict(_item) for _item in obj["recipients"]] if obj.get("recipients") is not None else None,
            "archived": obj.get("archived"),
            "type": obj.get("type") if obj.get("type") is not None else 'ASSIGNMENT',
            "assignedTo": obj.get("assignedTo"),
            "assignedFrom": obj.get("assignedFrom")
        })
        return _obj





import hubspot.crm.exports as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def public_exports_api(self) -> api_client.PublicExportsApi:
        return self._configure_api_client(api_client, "PublicExportsApi")
